# Note: much of this spec file is based off of the AUR PKGBUILD file hosted
# here: https://aur.archlinux.org/cgit/aur.git/tree/PKGBUILD?h=mattermost
%define debug_package %{nil}

Name:		mattermost-src
Version:	4.6.1
Release:	1%{?dist}
Summary:	Mattermost is an open source, self-hosted Slack-alternative
Group:		System Environment/Daemons
License:	AGPLv3 and ASL 2.0
URL:		https://mattermost.com
# Download latest with this URL: https://github.com/mattermost/platform/archive/master.tar.gz
# Server
# Spec Files are dumb and don't allow renaming files... User this URL to update
# source: https://github.com/mattermost/mattermost-server/archive/v%{version}.tar.gz
Source0:   mattermost-server.tar.gz
# Webapp: https://github.com/mattermost/mattermost-webapp/archive/v%{version}.tar.gz
Source1:  mattermost-webapp.tar.gz
Source2:	mattermost.service
Source3:	mattermost.sh
Source4:	mattermost.conf
Source5:	mattermost.tmpfiles
Patch0:		mm-ldap.patch
Patch1:   mattermost-server-makefile.patch

BuildRequires:	golang
BuildRequires:	git
BuildRequires:  python
BuildRequires:  resolv-conf
BuildRequires:  nodejs
BuildRequires:  libpng12
BuildRequires:  yarn

BuildArch:	x86_64

%description
As an alternative to proprietary SaaS messaging, Mattermost brings all your team
communication into one place, making it searchable and accessible anywhere. It’s
written in Golang and React and runs as a production-ready Linux binary under an
MIT license with either MySQL or Postgres.

Mattermost is:

 - Slack-compatible, not Slack-limited – Mattermost features rival Slack 
   features, and support a superset of Slack’s incoming and outgoing webhook 
   integrations, including compatibility with existing Slack integrations. From
   your existing Slack teams, you can import users, public channel history and 
   even theme setting colors into Mattermost.
 - Mobile and desktop apps, in addition to web – Use Mattermost from your iOS or
   Android phones and tablets or with installed apps on Windows, Linux and Mac.
 - Easy to deploy, manage, and upgrade – Mattermost runs as Linux binary, Docker
   image, and many other forms. Try Mattermost with a one-line Docker install, 
   and many install guides are available. Improvements ship monthly.
 - Supported by a vibrant community – Use Mattermost with dozens of community
   integrations and applications, including Jira, IRC, XMPP, Hubot, Giphy, 
   Jenkins, GitLab, Trac, Redmine, SVN, RSS/Atom and many others. Build and 
   share your own apps using Mattermost APIs and drivers.


%prep
cd %{_builddir}
tar xvvf %{SOURCE0}
tar xvvf %{SOURCE1}
# adapted from mattermost AUR PKGBUILD
mv mattermost-server-%{version} mattermost-server
mv mattermost-webapp-%{version} mattermost-webapp
pushd mattermost-server
%patch0 -p1
popd

mkdir -p src/github.com/mattermost
cd src/github.com/mattermost

# Remove previous platform folders if any previous clone was effective
rm -f mattermost-server
rm -f mattermost-webapp

# Create the directory structure to match Go namespaces
ln -s "%{_builddir}"/mattermost-server mattermost-server
ln -s "%{_builddir}"/mattermost-webapp mattermost-webapp
cd mattermost-server

# Apply patch to fix upstream blunder
%patch1 -p0

# We are not using docker, no need to stop it.
sed -r -i Makefile \
		-e 's/^clean: stop-docker/clean:/'

# Enforce build hash to CentOS 7 (Enterprise hash is already set to
# none), instead of the official git hash value.
# Also, vim doesn't seem to like these quotes :(
sed -r -i Makefile \
		-e "s/^(\s*)BUILD_HASH(_ENTERPRISE)? =.*/\1BUILD_HASH\2 = CentOS 7 \(x86_64\)/" \
		-e 's/-X (.*)(\$\(BUILD_HASH(_ENTERPRISE)?\))(.*)/-X '\''\1\2'\''\4/'

# The configuration is not available at this time yet, modify the default.
sed -r -i build/release.mk \
		-e 's/\$\(DIST_PATH\)\/config\/config.json/\$\(DIST_PATH\)\/config\/default.json/'

# Remove platform specific lines from the Makefile from the line beginning
# with that statement to the end of file (we do not care of the additional
# file copy, nor the tar compression defined below the file).
sed '/# ----- PLATFORM SPECIFIC -----/,//d' -i ./build/release.mk

%build
# No need to build mattermost-webapp as the server is taking care of this
# step via its build-client make instruction.

cd "%{_builddir}"/src/github.com/mattermost/mattermost-server
# Prevent the build to crash when some dependencies are not met or
# outdated. This clean the webapp as well (cf. mattermost-server/Makefile,
# clean target).
make clean
GOPATH="%{_builddir}" BUILD_NUMBER=%{version}-%{release} make build-linux
GOPATH="%{_builddir}" BUILD_NUMBER=%{version}-%{release} make build-client
GOPATH="%{_builddir}" BUILD_NUMBER=%{version}-%{release} make package

%install
cd "%{_builddir}"/src/github.com/mattermost/mattermost-server

install -dm755 \
		"%{buildroot}"/usr/share/webapps \
		"%{buildroot}"/var/log/mattermost \
		"%{buildroot}"/etc/webapps \
		"%{buildroot}"/usr/share/doc/mattermost

cp -a dist/mattermost "%{buildroot}"/usr/share/webapps/

cd "%{buildroot}"/usr/share/webapps/mattermost

rm -rf logs
ln -s /var/log/mattermost logs

cp config/default.json config/config.json
mv config "%{buildroot}"/etc/webapps/mattermost
ln -s /etc/webapps/mattermost config

sed -e 's@"Directory": ".*"@"Directory": "/var/lib/mattermost/"@g' \
		-e 's@tcp(dockerhost:3306)@unix(/run/mysqld/mysqld.sock)@g' \
		-i "%{buildroot}"/etc/webapps/mattermost/config.json

mv NOTICE.txt README.md "%{buildroot}"/usr/share/doc/mattermost

cd "%{_builddir}"
install -Dm755 bin/platform "%{buildroot}"/usr/share/webapps/mattermost/bin/
install -Dm644 %{SOURCE2} "%{buildroot}"/usr/lib/systemd/system/mattermost.service
install -Dm755 %{SOURCE3} "%{buildroot}"/usr/bin/mattermost
install -Dm600 %{SOURCE4} "%{buildroot}"/etc/nginx/conf.d/mattermost.conf
install -Dm644 %{SOURCE5} "%{buildroot}"/usr/lib/tmpfiles.d/mattermost.conf

%files
%defattr(660, mattermost, mattermost, 771)
/etc/webapps/*
/usr/share/webapps/mattermost/*
/usr/lib/tmpfiles.d/mattermost.conf
%attr(644, root, root) /usr/lib/systemd/system/mattermost.service
%attr(755, root, root) /usr/bin/mattermost
%config(noreplace) %attr(600, root, root) /etc/nginx/conf.d/mattermost.conf
%attr(755, mattermost, mattermost) /usr/share/webapps/mattermost/bin/platform
%config(noreplace) /etc/webapps/mattermost/config.json
%doc /usr/share/doc/mattermost/*

%pre
id -u mattermost &>/dev/null || useradd -r mattermost -U

%changelog
* Fri Feb 09 2018 Alexander Pavel <anp120@nbcs.rutgers.edu> - 4.6.1-1
- Re-enable ldap patch
- Major version bump
- Resync with AUR packaging (which is very well done)

* Mon Apr 24 2017 Alexander Pavel <anp120@nbcs.rutgers.edu> - 3.8.2-1
- Version bump

* Thu Apr 20 2017 Alexander Pavel <anp120@nbcs.rutgers.edu> - 3.8.1-1
- Version bump

* Thu Apr 13 2017 Alexander Pavel <anp120@nbcs.rutgers.edu> - 3.8.0-1
- Version bump

* Thu Mar 30 2017 Alexander Pavel <anp120@nbcs.rutgers.edu> - 3.7.3-2
- Remove nginx and postgresql requirements. These are not hard requirements
  (you can use a different webserver or db), and it makes the docker images 
  more bloated, so we are removing those requires.

* Mon Mar 27 2017 Alexander Pavel <anp120@nbcs.rutgers.edu> - 3.7.3-1
- Version bump

* Tue Mar 21 2017 Alexander Pavel <anp120@nbcs.rutgers.edu> - 3.7.2-1
- Version bump

* Mon Feb 13 2017 Alexander Pavel <anp120@nbcs.rutgers.edu> - 3.6.2-1
- Version bump

* Mon Nov 21 2016 Alexander Pavel <anp120@nbcs.rutgers.edu> - 3.5.0-2
- Don't try to create user if user already exists

* Thu Nov 17 2016 Alexander Pavel <anp120@nbcs.rutgers.edu> - 3.5.0-1
- Version bump

* Wed Sep 28 2016 Alexander Pavel <anp120@nbcs.rutgers.edu> - 3.4.0-1
- Move to mainline instead of git
- Update to version 3.4.0

* Thu Aug 11 2016 Alexander Pavel <anp120@jla.rutgers.edu> - 2016Aug11-1
- Version bump
- Build with golang 1.6.3, as the guys at CentOS finally updated it...

* Thu Aug 4 2016 Alexander Pavel <anp120@jla.rutgers.edu> - 2016Aug3-5
- Made nginx config noreplace

* Thu Aug 4 2016 Alexander Pavel <anp120@jla.rutgers.edu> - 2016Aug3-4
- Fix path for mattermost nginx conf

* Thu Aug 4 2016 Alexander Pavel <anp120@jla.rutgers.edu> - 2016Aug3-3
- Fix postgres dependency

* Thu Aug 4 2016 Alexander Pavel <anp120@jla.rutgers.edu> - 2016Aug3-2
- Include bin/platform (which is not it dist folder for some reason)
- Set attributes for files
- Add mattermost service
- Add mattermost nginx conf
- Add mattermost user
- Add mattermost shell script in /usr/bin
- Add nginx and postgresql dependencies

* Wed Aug 3 2016 Alexander Pavel <anp120@jla.rutgers.edu> - 2016Aug3-1
- Make git version
- Build from source
- Enable ldap for internal testing purposes

* Fri Jul 15 2016 Derek Maciel <dam402@nbcs.rutgers.edu> - 3.1.0-1
 - Initial build for Rutgers CentOS 7
